@@ -12,7 +12,7 @@ FONT = pkg_resources.resource_filename(__name__, 'resources/font.ttf')
 
 def draw_date(draw, date):
     font = ImageFont.truetype(FONT, FONT_SIZE)
-    draw.text((10, 40), "Дата и время: " + date.strftime("%Y-%m-%d %H:%M:%S"), font=font, fill=(0, 0, 0))
+    draw.text((10, 40), u"Дата и время: " + date.strftime("%Y-%m-%d %H:%M:%S"), font=font, fill=(0, 0, 0))
 
 
 def draw_longstring(draw, name, position):
